summaryrefslogtreecommitdiff
path: root/sensors-applet/sensors-applet.h
diff options
context:
space:
mode:
Diffstat (limited to 'sensors-applet/sensors-applet.h')
-rw-r--r--sensors-applet/sensors-applet.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/sensors-applet/sensors-applet.h b/sensors-applet/sensors-applet.h
index d561360..36c3c62 100644
--- a/sensors-applet/sensors-applet.h
+++ b/sensors-applet/sensors-applet.h
@@ -131,9 +131,9 @@ struct _SensorsApplet {
/* preferences and about windows (if Gtk < 2.6)*/
PrefsDialog *prefs_dialog;
/* primary table to contain the panel dispay - we pack the
* list of labels and sensor values into this container */
- GtkWidget *table;
+ GtkWidget *grid;
GList *active_sensors;
GSettings *settings;
@@ -131,9 +131,9 @@ struct _SensorsApplet {
/* preferences and about windows (if Gtk < 2.6)*/
PrefsDialog *prefs_dialog;
- /* primary table to contain the panel dispay - we pack the
+ /* primary grid to contain the panel dispay - we pack the
* list of labels and sensor values into this container */